@@ -95,6 +95,11 @@ class AccuWeather:
         ]
 
         for day in data:
+            # For some forecast days, the AccuWeather API does not provide an Ozone value.
+            day.setdefault("Ozone", {})
+            day["Ozone"].setdefault("Value")
+            day["Ozone"].setdefault("Category")
+
             for item in day["AirAndPollen"]:
                 if item["Name"] == "AirQuality":
                     day[item["Type"]] = item
@@ -195,7 +200,7 @@ class ApiError(Exception):
 
     def __init__(self, status):
         """Initialize."""
-        super(ApiError, self).__init__(status)
+        super().__init__(status)
         self.status = status
 
 
@@ -204,7 +209,7 @@ class InvalidApiKeyError(Exception):
 
     def __init__(self, status):
         """Initialize."""
-        super(InvalidApiKeyError, self).__init__(status)
+        super().__init__(status)
         self.status = status
 
 
@@ -213,7 +218,7 @@ class InvalidCoordinatesError(Exception):
 
     def __init__(self, status):
         """Initialize."""
-        super(InvalidCoordinatesError, self).__init__(status)
+        super().__init__(status)
         self.status = status
 
 
@@ -222,5 +227,5 @@ class RequestsExceededError(Exception):
 
     def __init__(self, status):
         """Initialize."""
-        super(RequestsExceededError, self).__init__(status)
+        super().__init__(status)
         self.status = status
